summaryrefslogtreecommitdiffstats
path: root/src/mbedTLS++/CallbackSslContext.h
diff options
context:
space:
mode:
authorpeterbell10 <peterbell10@live.co.uk>2017-08-30 16:00:06 +0200
committerTiger Wang <ziwei.tiger@outlook.com>2017-08-30 16:00:06 +0200
commit84941bcc9f25cbe3fd3b2604080d0a1cfd8fbaa7 (patch)
treeaa1648c2ba260b8576673677435481d371eec7b0 /src/mbedTLS++/CallbackSslContext.h
parentUpdate core plugins to latest version (#3951) (diff)
downloadcuberite-84941bcc9f25cbe3fd3b2604080d0a1cfd8fbaa7.tar
cuberite-84941bcc9f25cbe3fd3b2604080d0a1cfd8fbaa7.tar.gz
cuberite-84941bcc9f25cbe3fd3b2604080d0a1cfd8fbaa7.tar.bz2
cuberite-84941bcc9f25cbe3fd3b2604080d0a1cfd8fbaa7.tar.lz
cuberite-84941bcc9f25cbe3fd3b2604080d0a1cfd8fbaa7.tar.xz
cuberite-84941bcc9f25cbe3fd3b2604080d0a1cfd8fbaa7.tar.zst
cuberite-84941bcc9f25cbe3fd3b2604080d0a1cfd8fbaa7.zip
Diffstat (limited to '')
-rw-r--r--src/mbedTLS++/CallbackSslContext.h (renamed from src/PolarSSL++/CallbackSslContext.h)15
1 files changed, 8 insertions, 7 deletions
diff --git a/src/PolarSSL++/CallbackSslContext.h b/src/mbedTLS++/CallbackSslContext.h
index 1fc131182..da1abb707 100644
--- a/src/PolarSSL++/CallbackSslContext.h
+++ b/src/mbedTLS++/CallbackSslContext.h
@@ -1,4 +1,4 @@
-
+
// CallbackSslContext.h
// Declares the cCallbackSslContext class representing a SSL context wrapper that uses callbacks to read and write SSL peer data
@@ -10,6 +10,7 @@
#pragma once
#include "SslContext.h"
+#include "ErrorCodes.h"
@@ -26,17 +27,17 @@ public:
// Force a virtual destructor in descendants:
virtual ~cDataCallbacks() {}
- /** Called when PolarSSL wants to read encrypted data from the SSL peer.
- The returned value is the number of bytes received, or a PolarSSL error on failure.
- The implementation can return POLARSSL_ERR_NET_WANT_READ or POLARSSL_ERR_NET_WANT_WRITE to indicate
+ /** Called when mbedTLS wants to read encrypted data from the SSL peer.
+ The returned value is the number of bytes received, or a mbedTLS error on failure.
+ The implementation can return MBEDTLS_ERR_SSL_WANT_READ or MBEDTLS_ERR_SSL_WANT_WRITE to indicate
that there's currently no more data and that there might be more data in the future. In such cases the
SSL operation that invoked this call will terminate with the same return value, so that the owner is
notified of this condition and can potentially restart the operation later on. */
virtual int ReceiveEncrypted(unsigned char * a_Buffer, size_t a_NumBytes) = 0;
- /** Called when PolarSSL wants to write encrypted data to the SSL peer.
- The returned value is the number of bytes sent, or a PolarSSL error on failure.
- The implementation can return POLARSSL_ERR_NET_WANT_READ or POLARSSL_ERR_NET_WANT_WRITE to indicate
+ /** Called when mbedTLS wants to write encrypted data to the SSL peer.
+ The returned value is the number of bytes sent, or a mbedTLS error on failure.
+ The implementation can return MBEDTLS_ERR_SSL_WANT_READ or MBEDTLS_ERR_SSL_WANT_WRITE to indicate
that there's currently no more data and that there might be more data in the future. In such cases the
SSL operation that invoked this call will terminate with the same return value, so that the owner is
notified of this condition and can potentially restart the operation later on. */